==> hlint-3.3.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hlint
version:              3.3.1
visibility:           public
id:                   hlint-3.3.1-BKCaxLucTmF9vhIceLKXqP
key:                  hlint-3.3.1-BKCaxLucTmF9vhIceLKXqP
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2021
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  8bbba836b9aa4873a49f61df8cd64306
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Test.All Test.Annotations Test.InputOutput
    Test.Util

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hlint-3.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hlint-3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.3.1-BKCaxLucTmF9vhIceLKXqP
depends:
    aeson-1.5.6.0-KLnW8ZNssug7g6SUFAYcU2
    ansi-terminal-0.11-FDn5stAeTja6b4Fn65mtJG base-4.15.0.0
    bytestring-0.10.12.1 cmdargs-0.10.21-9JSptK8vQ5KGyQ5LWB6hlS
    containers-0.6.4.1 cpphs-1.20.9.1-24HoFEFAntoIruwEZ12WN8
    data-default-0.7.1.1-IvZDod4GR1F6QW3rWcNSTn directory-1.3.6.1
    extra-1.7.9-IPx7nrY9PGCFR1u9hKqJoo
    file-embed-0.0.14.0-DpVDNlFaM0M9fTuZiTfuRf filepath-1.4.2.1
    filepattern-0.1.2-LotZeDLCAODHJKGog4ppHB ghc-9.0.1 ghc-boot-9.0.1
    ghc-boot-th-9.0.1 ghc-lib-parser-ex-9.0.0.4-GRo1gQUVexREyMXuvMsrCi
    hscolour-1.24.4-V6n7Sl2OceF3ngsPSIix4 process-1.6.11.0
    refact-0.3.0.2-Gbe5JMXSilcL92y4ri1Ixm text-1.2.4.1
    transformers-0.5.6.2 uniplate-1.6.13-BoqXNa9sJ0L6LyPWaDdXv
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG
    yaml-0.11.5.0-Lmz0eU5eQ4e8LDdxW525UM

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hlint-3.3.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/hlint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hlint
version:              3.3.1
visibility:           public
id:                   hlint-3.3.1-6NWUhxkvZoYKehZ8rzYudr
key:                  hlint-3.3.1-6NWUhxkvZoYKehZ8rzYudr
license:              BSD-3-Clause
copyright:            Neil Mitchell 2006-2021
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/hlint#readme
synopsis:             Source code suggestions
description:          HLint gives suggestions on how to improve your source code.
category:             Development
abi:                  9e136df755692fe1f51cace5df6813dc
exposed:              True
exposed-modules:      Language.Haskell.HLint
hidden-modules:
    Paths_hlint Apply CmdLine Extension Fixity HLint HsColour Idea
    Report Util Parallel Refact Timing CC EmbedData Summary
    Config.Compute Config.Haskell Config.Read Config.Type Config.Yaml
    GHC.All GHC.Util GHC.Util.ApiAnnotation GHC.Util.View
    GHC.Util.Brackets GHC.Util.DynFlags GHC.Util.FreeVars
    GHC.Util.HsDecl GHC.Util.HsExpr GHC.Util.SrcLoc GHC.Util.Scope
    GHC.Util.Unify Hint.All Hint.Bracket Hint.Comment Hint.Duplicate
    Hint.Export Hint.Extensions Hint.Fixities Hint.Import Hint.Lambda
    Hint.List Hint.ListRec Hint.Match Hint.Monad Hint.Naming
    Hint.NewType Hint.Pattern Hint.Pragma Hint.Restrict Hint.Smell
    Hint.Type Hint.Unsafe Test.All Test.Annotations Test.InputOutput
    Test.Util

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hlint-3.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hlint-3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hlint
hs-libraries:         HShlint-3.3.1-6NWUhxkvZoYKehZ8rzYudr
depends:
    aeson-1.5.6.0-nrMp0b6teF7D3JqNhCf9o
    ansi-terminal-0.11-FDn5stAeTja6b4Fn65mtJG base-4.15.0.0
    bytestring-0.10.12.1 cmdargs-0.10.21-9JSptK8vQ5KGyQ5LWB6hlS
    containers-0.6.4.1 cpphs-1.20.9.1-24HoFEFAntoIruwEZ12WN8
    data-default-0.7.1.1-IvZDod4GR1F6QW3rWcNSTn directory-1.3.6.1
    extra-1.7.10-BvdTl6cjCa8NOGkBoNpwW
    file-embed-0.0.14.0-DpVDNlFaM0M9fTuZiTfuRf filepath-1.4.2.1
    filepattern-0.1.2-3DibeBOzpymDiu5rVU0tIv ghc-9.0.1 ghc-boot-9.0.1
    ghc-boot-th-9.0.1 ghc-lib-parser-ex-9.0.0.4-KaKYe4pBzsk6znzR3ZwS9t
    hscolour-1.24.4-V6n7Sl2OceF3ngsPSIix4 process-1.6.11.0
    refact-0.3.0.2-Gbe5JMXSilcL92y4ri1Ixm text-1.2.4.1
    transformers-0.5.6.2 uniplate-1.6.13-BoqXNa9sJ0L6LyPWaDdXv
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG
    yaml-0.11.5.0-IHc8QUc4dzU7mXeqXvn6T5

haddock-interfaces:   /usr/share/doc/hlint/html/hlint.haddock
haddock-html:         /usr/share/doc/hlint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
